# License information:
#
# This code is largely a Perl wrapper around data tables provided by the
# Unicode Consortium under their Unicode Character Database Terms Of Use
#
# Upstream is happy for us to distribute the Perl parts under any terms
# we like, so I have selected the standard "same as Perl" terms of
# "GPL+ or Artistic"
#
# Ref: https://rt.cpan.org/Public/Bug/Display.html?id=70210

# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Checks if scalar is valid UTF-8
Name:		perl-Unicode-CheckUTF8
Version:	1.03
Release:	39.%{__distinit}%{__distvers}
# CheckUTF8.xs is UCD, no SPDX version of that license yet
# Maybe it's been replaced by the Unicode Terms of Use license?
License:	UCD and (GPL+ or Artistic)
URL:		https://metacpan.org/release/Unicode-String
Source0:	https://cpan.metacpan.org/modules/by-module/Unicode/Unicode-CheckUTF8-%{version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(XSLoader)
# Test Suite
BuildRequires:	perl(Test::More)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Don't "provide" private Perl libs
%{?perl_default_filter}

%description
This is an XS wrapper around some Unicode Consortium code to check if a string
is valid UTF-8, revised to conform to what expat/Mozilla think is valid UTF-8,
especially with regard to low-ASCII characters.

Note that this module has NOTHING to do with Perl's internal UTF8 flag on
scalars.

This module is for use when you're getting input from users and want to make
sure it's valid UTF-8 before continuing.

%prep
%setup -q -n Unicode-CheckUTF8-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc CHANGES
%{perl_vendorarch}/Unicode/
%{perl_vendorarch}/auto/Unicode/
%{_mandir}/man3/Unicode::CheckUTF8.3*

%changelog
* Mon Jan 22 2024 Paul Howarth <paul@city-fan.org> - 1.03-39
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Tue Jul 11 2023 Paul Howarth <paul@city-fan.org> - 1.03-37
- Perl 5.38 rebuild

* Tue May 31 2022 Paul Howarth <paul@city-fan.org> - 1.03-34
- Perl 5.36 rebuild

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 1.03-32
- Perl 5.34 rebuild

* Wed Jun 24 2020 Paul Howarth <paul@city-fan.org> - 1.03-29
- Perl 5.32 rebuild

* Thu May 30 2019 Paul Howarth <paul@city-fan.org> - 1.03-25
- Perl 5.30 rebuild

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 1.03-22
- Perl 5.28 rebuild

* Sat Aug  5 2017 Paul Howarth <paul@city-fan.org> - 1.03-20
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Mon Jun 12 2017 Paul Howarth <paul@city-fan.org> - 1.03-18
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Tue May 17 2016 Paul Howarth <paul@city-fan.org> - 1.03-16
- Classify builreqs by usage
- BR: perl-devel and perl-generators where available
- Simplify find commands using -empty and -delete

* Tue Sep  2 2014 Paul Howarth <paul@city-fan.org> - 1.03-11
- Drop %%defattr, redundant since rpm 4.4

* Tue Jun 12 2012 Paul Howarth <paul@city-fan.org> - 1.03-4
- BR: perl(base), perl(Exporter) and perl(XSLoader)
- Note that CheckUTF8.xs is UCD licensed
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Drop perl ≥ 5.8.1 buildreq, satisfied by all supported distributions
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Thu Aug 11 2011 Paul Howarth <paul@city-fan.org> - 1.03-1
- Initial RPM version
